Preferences/ConfigurationDialog.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 53
c3eb7cc1ff8b
--- a/Preferences/ConfigurationDialog.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/Preferences/ConfigurationDialog.py	Sat Jan 02 17:09:08 2010 +0000
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog for the configuration of eric4.
+Module implementing a dialog for the configuration of eric5.
 """
 
 import os
@@ -22,7 +22,7 @@
 from .PreferencesLexer import PreferencesLexer, PreferencesLexerLanguageError
 import UI.PixmapCache
 
-from eric4config import getConfig
+from eric5config import getConfig
 
 class ConfigurationPageItem(QTreeWidgetItem):
     """
@@ -52,7 +52,7 @@
 
 class ConfigurationWidget(QWidget):
     """
     Class implementing a dialog for the configuration of eric4.
     
     @signal preferencesChanged emitted after settings have been changed
     """
@@ -62,7 +62,7 @@
         
         @param parent The parent widget of this dialog. (QWidget)
         @keyparam fromEric flag indicating a dialog generation from within the 
-            eric4 ide (boolean)
+            eric5 ide (boolean)
         @keyparam helpBrowserMode flag indicating to show only help pages
             for entries related to the help browser (boolean)
         """
@@ -585,7 +585,7 @@
         @param name The name of this dialog. string
         @param modal Flag indicating a modal dialog. (boolean)
         @keyparam fromEric flag indicating a dialog generation from within the 
-            eric4 ide (boolean)
+            eric5 ide (boolean)
         @keyparam helpBrowserMode flag indicating to show only help pages
             for entries related to the help browser (boolean)
         """
@@ -663,4 +663,4 @@
         self.cw.setPreferences()
         Preferences.saveResetLayout()
         Preferences.syncPreferences()
-        self.close()
+        self.close()
\ No newline at end of file
@@ -52,7 +52,7 @@
 class ConfigurationWidget(QWidget):
     """
-    Class implementing a dialog for the configuration of eric4.
+    Class implementing a dialog for the configuration of eric5.
     
     @signal preferencesChanged emitted after settings have been changed

eric ide

mercurial